FirebaseCrashlyticsHostApi class

Constructors

FirebaseCrashlyticsHostApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
Constructor for FirebaseCrashlyticsHostApi. The binaryMessenger named argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.

Properties

hashCode int
The hash code for this object.
no setterinherited
pigeonVar_binaryMessenger BinaryMessenger?
final
pigeonVar_messageChannelSuffix String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkForUnsentReports() Future<bool>
crash() Future<void>
deleteUnsentReports() Future<void>
didCrashOnPreviousExecution() Future<bool>
log(String message) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordError(RecordErrorRequest request) Future<void>
sendUnsentReports() Future<void>
setCrashlyticsCollectionEnabled(bool enabled) Future<bool>
setCustomKey(String key, String value) Future<void>
setUserIdentifier(String identifier) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

pigeonChannelCodec → const MessageCodec<Object?>