CrashlyticsStackFrame class

Constructors

CrashlyticsStackFrame({String? className, required String method, required String file, required String line})

Properties

className ↔ String?
Dart reserved word class; native maps this to the historical "class" key.
getter/setter pair
file ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
line ↔ String
getter/setter pair
method ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

decode(Object result) → CrashlyticsStackFrame