RecordErrorRequest class
Constructors
-
RecordErrorRequest({required String exception, required String information, String? reason, required bool fatal, required String buildId, required List<
String> loadingUnits, required List<CrashlyticsStackFrame> stackTraceElements})
Properties
- buildId ↔ String
-
getter/setter pair
- exception ↔ String
-
getter/setter pair
- fatal ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- information ↔ String
-
getter/setter pair
-
loadingUnits
↔ List<
String> -
getter/setter pair
- reason ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stackTraceElements
↔ List<
CrashlyticsStackFrame> -
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
decode(
Object result) → RecordErrorRequest