TestFirebaseCrashlyticsHostApi class abstract

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkForUnsentReports() → Future<bool>
crash() → Future<void>
deleteUnsentReports() → Future<void>
didCrashOnPreviousExecution() → Future<bool>
log(String message) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordError(RecordErrorRequest request) → Future<void>
sendUnsentReports() → Future<void>
setCrashlyticsCollectionEnabled(bool enabled) → Future<bool>
setCustomKey(String key, String value) → Future<void>
setUserIdentifier(String identifier) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

setUp(TestFirebaseCrashlyticsHostApi? api, {BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''}) → void

Constants

pigeonChannelCodec → const MessageCodec<Object?>